@@ -191,7 +191,20 @@ class MessageGenerator:
         logger.debug("Generating local messages...")
         local_path = os.path.join(os.path.dirname(__file__), "..")
         logger.debug(f"local_path: {local_path}")
-        for package in ["std_msgs", "rosgraph_msgs"]:
+        local_message_packages = [
+            "std_msgs",
+            "rosgraph_msgs",
+            "actionlib_msgs",
+            "diagnostic_msgs",
+            "geometry_msgs",
+            "nav_msgs",
+            "sensor_msgs",
+            "shape_msgs",
+            "stereo_msgs",
+            "trajectory_msgs",
+            "visualization_msgs",
+        ]
+        for package in local_message_packages:
             msg_dir = f"{local_path}/definitions/{package}/msg"
             search_path[package] = [msg_dir]
             package_files = []
